County Economic Status in Appalachia, FY 2004 - Appalachian Regional Commission
Description: This map shows ARC’s economic classification of the Region's counties for FY 2004.
Keywords: economic status maps, maps, County Economic Status in Appalachia, FY 2004

hide You are viewing an archived web page collected at the request of Federal Depository Library Program Web Archive using Archive-It. This page was captured on 14:18:18 Mar 18, 2016, and is part of the ARC, Appalachian Regional Commission collection. The information on this web page may be out of date. See All versions of this archived page. Found 0 archived media items out of 0 total on this page.
Enable QA View Missing URLs
<
?
>
Search ARC

## County Economic Status in Appalachia, FY 2004

(Effective October 1, 2003 through September 30, 2004)

Each fiscal year the Appalachian Regional Commission classifies the Region’s counties into one of four economic levels based on a comparison of county and national rates for three economic indicators: three-year average unemployment rates, per-capita market income rates, and poverty rates. See the methodology for a description of each economic level.

Map Options
Print
Related Files
PDF version of the map (400 KB)
Excel file of supporting data for the map (90 KB)
Related Links
Data Report
Source and Methodology